@@ -233,7 +233,7 @@ sub login {
     }
     else{
         $self->qrcode_count(0);
-        $self->info("帐号(" . $self->account . ")登录成功");
+        $self->info("帐号(" .( $self->uid // $self->account) . ")登录成功");
         $self->login_type eq "qrlogin"?$self->clean_qrcode():$self->clean_verifycode();
         $self->state('updating');
         $self->update_user;
@@ -445,4 +445,9 @@ sub save_state{
     $self->warn("客户端状态信息保存失败：$@") if $@;
 }
 
+sub is_load_plugin {
+    my $self = shift;
+    my $plugin = shift;
+    return exists $self->plugins->{ substr($plugin,0,1) eq '+'?$plugin:"Mojo::Webqq::Plugin::$plugin" };
+}
 1;
